@@ -33,6 +33,8 @@
 #' data.table.
 #' @param t_test_df_decimals number of decimals for the degrees of freedom
 #' in t-tests (default = 1)
+#' @param round_p number of decimal places to which to round
+#' p-values (default = 3)
 #' @param save_as_png if \code{save = "all"} or if \code{save = TRUE},
 #' the histogram by group, descriptive statistics by group,
 #' and pairwise comparison results will be saved as a PNG file.
@@ -95,6 +97,7 @@ compare_groups <- function(
   mann_whitney = TRUE,
   t_test_stats = FALSE,
   t_test_df_decimals = 1,
+  round_p = 3,
   save_as_png = FALSE,
   png_name = NULL,
   xlab = NULL,
@@ -119,7 +122,7 @@ compare_groups <- function(
   # descriptive stats by group
   output_2 <- kim::desc_stats_by_group(
     data = data, var_for_stats = dv_name, grouping_vars = iv_name,
-    sigfigs = sigfigs, stats = "basic")
+    sigfigs = sigfigs, stats = stats)
   # pairwise comparison results
   output_3 <- kim::t_test_pairwise(
     data = data, iv_name = iv_name, dv_name = dv_name,
@@ -129,7 +132,8 @@ compare_groups <- function(
     bonferroni = bonferroni,
     mann_whitney = mann_whitney,
     t_test_stats = t_test_stats,
-    t_test_df_decimals = t_test_df_decimals)
+    t_test_df_decimals = t_test_df_decimals,
+    round_p = round_p)
   # print outputs
   output_1
   output_2
